@@ -2,7 +2,7 @@
 nydus.db.backends.redis
 ~~~~~~~~~~~~~~~~~~~~~~~
 
-:copyright: (c) 2011 DISQUS.
+:copyright: (c) 2011-2012 DISQUS.
 :license: Apache License 2.0, see LICENSE for more details.
 """
 
@@ -22,7 +22,9 @@ class RedisPipeline(BasePipeline):
 
     def add(self, command):
         self.pending.append(command)
-        getattr(self.pipe, command._attr)(*command._args, **command._kwargs)
+        name, args, kwargs = command.get_command()
+        # ensure the command is executed in the pipeline
+        getattr(self.pipe, name)(*args, **kwargs)
 
     def execute(self):
         return self.pipe.execute()
@@ -33,15 +35,15 @@ class Redis(BaseConnection):
     retryable_exceptions = frozenset([RedisError])
     supports_pipelines = True
 
-    def __init__(self, host='localhost', port=6379, db=0, timeout=None,
-        password=None, unix_socket_path=None, **options):
+    def __init__(self, num, host='localhost', port=6379, db=0, timeout=None,
+                 password=None, unix_socket_path=None):
         self.host = host
         self.port = port
         self.db = db
         self.unix_socket_path = unix_socket_path
         self.timeout = timeout
         self.__password = password
-        super(Redis, self).__init__(**options)
+        super(Redis, self).__init__(num)
 
     @property
     def identifier(self):
@@ -50,7 +52,8 @@ class Redis(BaseConnection):
         return "redis://%(host)s:%(port)s/%(db)s" % mapping
 
     def connect(self):
-        return RedisClient(host=self.host, port=self.port, db=self.db,
+        return RedisClient(
+            host=self.host, port=self.port, db=self.db,
             socket_timeout=self.timeout, password=self.__password,
             unix_socket_path=self.unix_socket_path)
 
