@@ -2,7 +2,7 @@
 nydus.db.backends.riak
 ~~~~~~~~~~~~~~~~~~~~~~
 
-:copyright: (c) 2011 DISQUS.
+:copyright: (c) 2011-2012 DISQUS.
 :license: Apache License 2.0, see LICENSE for more details.
 """
 
@@ -35,8 +35,9 @@ class Riak(BaseConnection):
         return "http://%(host)s:%(port)s/%(prefix)s" % mapping
 
     def connect(self):
-        return RiakClient(host=self.host, port=self.port, prefix=self.prefix,\
-                mapred_prefix=self.mapred_prefix, client_id=self.client_id)
+        return RiakClient(
+            host=self.host, port=self.port, prefix=self.prefix,
+            mapred_prefix=self.mapred_prefix, client_id=self.client_id)
 
     def disconnect(self):
         pass
